[asterisk-scf-commits] asterisk-scf/release/cmake.git branch "master" updated.

Commits to the Asterisk SCF project code repositories asterisk-scf-commits at lists.digium.com
Wed Sep 29 08:12:09 CDT 2010


branch "master" has been updated
       via  2bc8a018ed175d2f4155a3be171d23967052d627 (commit)
       via  44ed0b0ebbb2ed56321c922c41e9a51db04a6af6 (commit)
       via  f17d97cdd965cb9ecc1b0c6eab566170fa2622ff (commit)
      from  d30f7d1a5561c2bf086eacad2e0565c49c261e51 (commit)

Summary of changes:
 AsteriskSCF.cmake       |    8 ++++----
 CPackConfig.cmake       |   10 +++++-----
 README.txt              |    4 ++--
 example/CMakeLists.txt  |   18 +++++++++---------
 example/CPackConfig.txt |    4 ++--
 modules/pjproject.cmake |   14 ++++++++++++++
 6 files changed, 36 insertions(+), 22 deletions(-)


- Log -----------------------------------------------------------------
commit 2bc8a018ed175d2f4155a3be171d23967052d627
Author: Kevin P. Fleming <kpfleming at digium.com>
Date:   Wed Sep 29 08:08:53 2010 -0500

    teach pjproject.cmake how to search for libuuid and link it into components that
    use pjmedia, because pjmedia will use it if is present on the system

diff --git a/modules/pjproject.cmake b/modules/pjproject.cmake
index 055f625..44315eb 100644
--- a/modules/pjproject.cmake
+++ b/modules/pjproject.cmake
@@ -2,6 +2,17 @@
 # out about threads for when we do our linking.
 find_package(Threads)
 
+# The pjproject code will use libuuid if it is installed; in this situation, we need to be aware of it so we can link our components
+# with that library as well (since the pjproject libraries can't indicate to the linker that libuuid is needed).
+include(FindPkgConfig)
+pkg_check_modules(LIBUUID uuid)
+if(LIBUUID_LIBRARIES)
+  set(PJMEDIA_LIBRARIES ${LIBUUID_LIBRARIES} CACHE INTERNAL Bob FORCE)
+  if(LIBUUID_LIBRARY_DIRS)
+    link_directories(${LIBUUID_LIBRARY_DIRS})
+  endif()
+endif()
+
 # These are global targets which exist for all pjproject components, they are used for initial running of configure plus cleanup
 add_custom_command(OUTPUT "${CMAKE_SOURCE_DIR}/pjproject/build.mak" COMMAND "./configure" "--disable-sound" "--disable-ssl" WORKING_DIRECTORY "${CMAKE_SOURCE_DIR}/pjproject" COMMENT "Configuring pjproject")
 add_custom_command(OUTPUT "${CMAKE_SOURCE_DIR}/pjproject/pjlib/include/pj/config_site.h" COMMAND "make" "dep" "TARGET_NAME=asteriskscf" WORKING_DIRECTORY "${CMAKE_SOURCE_DIR}/pjproject" COMMENT "Dependency generating pjproject" DEPENDS "${CMAKE_SOURCE_DIR}/pjproject/build.mak")
@@ -70,6 +81,9 @@ function(pjproject_link COMPONENT PJPROJECT_COMPONENT)
       target_link_libraries(${COMPONENT} "pjsdp-asteriskscf")
       target_link_libraries(${COMPONENT} "pjmedia-audiodev-asteriskscf")
       target_link_libraries(${COMPONENT} "srtp-asteriskscf")
+      if(PJMEDIA_LIBRARIES)
+	target_link_libraries(${COMPONENT} ${PJMEDIA_LIBRARIES})
+      endif()
     else()
       target_link_libraries(${COMPONENT} "${PJPROJECT_COMPONENT}-asteriskscf")
     endif()

commit 44ed0b0ebbb2ed56321c922c41e9a51db04a6af6
Author: Kevin P. Fleming <kpfleming at digium.com>
Date:   Wed Sep 29 08:08:13 2010 -0500

    minor coding style fixes

diff --git a/AsteriskSCF.cmake b/AsteriskSCF.cmake
index 8be8c2d..603d890 100644
--- a/AsteriskSCF.cmake
+++ b/AsteriskSCF.cmake
@@ -581,7 +581,7 @@ function(hydra_compile_slice TARGET_IN DIR_IN DESC_IN GROUP_IN)
       DEPENDS ${slice_files} ${source_dependencies}
       )
 
-    if (target_CXX_includes)
+    if(target_CXX_includes)
       list(REMOVE_DUPLICATES target_CXX_includes)
     endif()
 
@@ -602,7 +602,7 @@ function(hydra_compile_slice TARGET_IN DIR_IN DESC_IN GROUP_IN)
       include_directories(${target_CXX_includes})
       add_library(${TARGET}_${lang} ${generated_files} ${slice_files})
       install(TARGETS ${TARGET}_${lang} DESTINATION ${DIR_IN} COMPONENT ${TARGET}_${lang})
-      if (ASTERISKSCF_CPACK)
+      if(ASTERISKSCF_CPACK)
          # Adds a component to the packager. The first arg must have been previously defined
 	 # as a COMPONENT arg to install. 
          cpack_add_component(${TARGET}_${lang} DESCRIPTION ${DESC_IN} GROUP ${GROUP_IN})
@@ -821,7 +821,7 @@ endfunction()
 function(hydra_component_install COMPONENTNAME TYPE DIR DESC GROUP)
   install(TARGETS ${COMPONENTNAME} ${TYPE} DESTINATION ${DIR} COMPONENT ${COMPONENTNAME} ${ARGN})
 
-   if (ASTERISKSCF_CPACK)
+   if(ASTERISKSCF_CPACK)
       hydra_component_package(${COMPONENTNAME} ${DESC} ${GROUP})
    endif()
 endfunction()

commit f17d97cdd965cb9ecc1b0c6eab566170fa2622ff
Author: Kevin P. Fleming <kpfleming at digium.com>
Date:   Wed Sep 29 07:43:53 2010 -0500

    replace a few more Hydra references with Asterisk SCF

diff --git a/AsteriskSCF.cmake b/AsteriskSCF.cmake
index eb35039..8be8c2d 100644
--- a/AsteriskSCF.cmake
+++ b/AsteriskSCF.cmake
@@ -1,4 +1,4 @@
-# Hydra component build infrastructures
+# Asterisk SCF component build infrastructure
 
 #
 # Copyright (C) 2010 - Digium, Inc.
@@ -602,7 +602,7 @@ function(hydra_compile_slice TARGET_IN DIR_IN DESC_IN GROUP_IN)
       include_directories(${target_CXX_includes})
       add_library(${TARGET}_${lang} ${generated_files} ${slice_files})
       install(TARGETS ${TARGET}_${lang} DESTINATION ${DIR_IN} COMPONENT ${TARGET}_${lang})
-      if (HYDRA_CPACK)
+      if (ASTERISKSCF_CPACK)
          # Adds a component to the packager. The first arg must have been previously defined
 	 # as a COMPONENT arg to install. 
          cpack_add_component(${TARGET}_${lang} DESCRIPTION ${DESC_IN} GROUP ${GROUP_IN})
@@ -821,7 +821,7 @@ endfunction()
 function(hydra_component_install COMPONENTNAME TYPE DIR DESC GROUP)
   install(TARGETS ${COMPONENTNAME} ${TYPE} DESTINATION ${DIR} COMPONENT ${COMPONENTNAME} ${ARGN})
 
-   if (HYDRA_CPACK)
+   if (ASTERISKSCF_CPACK)
       hydra_component_package(${COMPONENTNAME} ${DESC} ${GROUP})
    endif()
 endfunction()
diff --git a/README.txt b/README.txt
index 2cbe4ba..a2178f6 100644
--- a/README.txt
+++ b/README.txt
@@ -1,2 +1,2 @@
-This directory contains a common cmake build system for Hydra components. It is strongly
-advised that you look at the example provided for usage.
\ No newline at end of file
+This directory contains a common CMake build system for Asterisk SCF components. It is strongly
+advised that you look at the example provided for usage.
diff --git a/example/CMakeLists.txt b/example/CMakeLists.txt
index 12f20dd..9a490ba 100644
--- a/example/CMakeLists.txt
+++ b/example/CMakeLists.txt
@@ -1,24 +1,24 @@
-# This is an example CMakeLists.txt file for use with the Hydra component common build system
+# This is an example CMakeLists.txt file for use with the Asterisk SCF component common build system
 
 # You should specify the minimum version of cmake that is allowed. Unless you are using things that
-# require a higher version OR the Hydra.cmake file requires a higher version this can be left at 2.6
+# require a higher version OR the Asterisk SCF.cmake file requires a higher version this can be left at 2.6
 cmake_minimum_required(VERSION 2.6)
 
 # This allows you to use the CPack package builder. You must install some package building generator, 
 # such as NullSoft Installer (NSI) on Windows. 
-# This step is optional. While Hydra_v4.cmake has CPack-specific calls, they are only executed when
-# HYDRA_CPACK is set TRUE. This project-specific include sets this variable and sets other 
+# This step is optional. While AsteriskSCF_v4.cmake has CPack-specific calls, they are only executed when
+# ASTERISKSCF_CPACK is set TRUE. This project-specific include sets this variable and sets other 
 # project-specific values. 
 include(CPackConfig.txt)
 
-# In order to use the Hydra component common build system it has to be included into this CMakeLists.txt
+# In order to use the Asterisk SCF component common build system it has to be included into this CMakeLists.txt
 # so that the functions become available. If you are using svn:externals to get the build system this will
 # need to be changed to include the directory it exists in. For example if you have it being pulled into
 # the cmake directory you would use:
 #
-# include(cmake/Hydra_v4.cmake)
+# include(cmake/AsteriskSCF_v4.cmake)
 #
-include(../Hydra_v4.cmake)
+include(../AsteriskSCF_v4.cmake)
 
 # Note that the only valid languages for the following functions are: CXX (for C++) and CSharp (for C#)
 
@@ -38,14 +38,14 @@ hydra_project(example 3.4 CXX)
 
 # This function takes a component name and language. It initializes core data used for keeping
 # track of component Slice definitions, sources, and other things for a component. It *must* be
-# called before executing any other Hydra component function. This function also does dependency
+# called before executing any other Asterisk SCF component function. This function also does dependency
 # checking unique to the language specified.
 hydra_component_init(examplebox CXX)
 
 # If you have additional third party dependencies for your component the CMake logic to find them can be
 # inserted here.
 
-# It is extremely important to put HYDRA_ICEBOX_EXPORT before the name of your derived IceBox service
+# It is extremely important to put ASTERISKSCF_ICEBOX_EXPORT before the name of your derived IceBox service
 # class. When compiling on Windows this will get defined so that the class is exported allowing the service
 # to be loaded. If you do not put this in your component will not work on Windows.
 
diff --git a/example/CPackConfig.txt b/example/CPackConfig.txt
index aba1456..5b07cf1 100644
--- a/example/CPackConfig.txt
+++ b/example/CPackConfig.txt
@@ -1,6 +1,6 @@
 
-# This flag must be set to enable CPack support in Hydra_v4.cmake.
-set (HYDRA_CPACK "TRUE")
+# This flag must be set to enable CPack support in AsteriskSCF_v4.cmake.
+set (ASTERISKSCF_CPACK "TRUE")
 
 # CPack properties must be set prior to including CPack. 
 set (CPACK_PACKAGE_NAME "Time Machine")

-----------------------------------------------------------------------


diff --git a/CPackConfig.cmake b/CPackConfig.cmake
index f97c224..6a72e1d 100644
--- a/CPackConfig.cmake
+++ b/CPackConfig.cmake
@@ -1,10 +1,10 @@
 
-# This flag must be set to enable CPack support in Hydra_v4.cmake.
-set (HYDRA_CPACK "TRUE")
+# This flag must be set to enable CPack support in AsteriskSCF_v4.cmake.
+set (ASTERISKSCF_CPACK "TRUE")
 
 # CPack properties must be set prior to including CPack. 
-set (CPACK_PACKAGE_NAME "Hydra Core")
-set (CPACK_PACKAGE_INSTALL_DIRECTORY "Hydra Core 1.0.alpha")
+set (CPACK_PACKAGE_NAME "AsteriskSCF Core")
+set (CPACK_PACKAGE_INSTALL_DIRECTORY "AsteriskSCF Core 1.0.alpha")
 set (CPACK_PACKAGE_DESCRIPTION_FILE "X:/techdemo/trunk/packagefiles/Description.txt")
 set (CPACK_RESOURCE_FILE_LICENSE "X:/techdemo/trunk/packagefiles/License.txt")
 set (CPACK_RESOURCE_FILE_README "X:/techdemo/trunk/packagefiles/ReadMe.txt")
@@ -16,6 +16,6 @@ set (CPACK_PACKAGE_VERSION_PATCH "alpha")
 include(CPACK)
 
 # Define the Groups of components. 
-cpack_add_component_group("Core" "Hydra Core" "Core runtime component required for operation")
+cpack_add_component_group("Core" "AsteriskSCF Core" "Core runtime component required for operation")
 cpack_add_component_group("Utility" "Utiltity" "Optional utility application.")
 cpack_add_component_group("Test" "Test" "Test drivers.")
-- 
asterisk-scf/release/cmake.git



More information about the asterisk-scf-commits mailing list